/**
 * This is the main Brian MMA7455 Accelerometer program file.
 */

#include "simpletools.h"
//#include "mma7455.h"
#include "abdrive.h"

i2c *bus;                            //Declare I2C bus

void Gyro(void *par);
 
unsigned char i2cAddr  = 0x69;      // I2C address of Gyro
unsigned char devId  = 0x0f;        // Device ID
unsigned char ctrl1  = 0x20;        // Control reg1
unsigned char cfg1   = 0b00011111;  //100hz, 25 cutoff, power up, axes enable
unsigned char ctrl2  = 0x21;       
unsigned char ctrl3  = 0x22;
unsigned char cfg3   = 0b00001000;  //Enable data poling (I2_DRDY)
unsigned char ctrl4  = 0x23;
unsigned char cfg4   = 0b10000000;  //Block until read, big endian
unsigned char status = 0x27;
unsigned char xL     = 0x28;        //Reg for x low byte
unsigned char oxi    = 0xA8;

unsigned char reply;
char xyz[6];                        //XYZ dat array

static volatile int Gx, Gy, Gz;     //Global vars for cogs to share

unsigned int stack[128];             //Stack vars for second cog used

int dl, dr;

int main()
{
  bus = i2c_newbus(1, 0, 0);          //New I2C bus SCL = P5, SDA = P4

  //int cog = cogstart(&Accec, NULL, stack, sizeof(stack)); 
  //int cog1 = cogstart(&Gyro, NULL, stacka, sizeof(stacka));
  //cogstart(&Gyro, NULL, stacka, sizeof(stacka));
  cogstart(&Gyro, NULL, stack, sizeof(stack));
  
  drive_setRampStep(12);
  
  while(1)
  {
    dl = Gy * -5;
    
    drive_rampStep(dl, dl);
    
    pause(5);

  }
}

void Gyro(void *par)
{

   int n;
   n  = i2c_out(bus, i2cAddr, ctrl3, 1, &cfg3, 1);
   n += i2c_out(bus, i2cAddr, ctrl4, 1, &cfg4, 1);
   n += i2c_out(bus, i2cAddr, ctrl1, 1, &cfg1, 1); 

   if(n != 9)
   { 
     print("Bytes should be 9, but was %d, ", n);
     while(1);
   }
  
    while(1)
    {
    int ready = 0;        //Wait until ready
    while(!ready)
    {
      i2c_in(bus, i2cAddr, status, 1, &ready, 1);
      ready = 1 & (ready >>= 3);
    }
    for(int i = 0; i < 6; i++)
    {
      int regAddr = xL + i;
      i2c_in(bus, i2cAddr, regAddr, 1, &xyz[i], 1);
    }
    //Bytes to int
    Gx = (int) (short) ((xyz[1] << 8) + xyz[0]) / 114;
    Gy = (int) (short) ((xyz[3] << 8) + xyz[2]) / 114; 
    Gz = (int) (short) ((xyz[5] << 8) + xyz[4]) / 114;
    
    pause(5);
    }

}          

/*
short Accec(void *par)
{
  MMA7455_init(9, 10, 8);   //I/O to: DATA, CLK, /CS

  MMA7455_setOffsetX(29);
  MMA7455_setOffsetY(59);
  MMA7455_setOffsetZ(-60);
    
  while(1)
  {
    MMA7455_getxyz10(&Ax, &Ay, &Az);
   
   }
}
*/